@@ -10,20 +10,23 @@ use Rose::DB::Object::MakeMethods::Date;
 use Rose::DB::Object::Metadata::Column;
 our @ISA = qw(Rose::DB::Object::Metadata::Column);
 
-our $VERSION = '0.02';
+our $VERSION = '0.04';
 
-__PACKAGE__->add_method_maker_argument_names('default', 'type');
+__PACKAGE__->add_common_method_maker_argument_names('default', 'type');
 
 Rose::Object::MakeMethods::Generic->make_methods
 (
   { preserve_existing => 1 },
-  scalar => [ __PACKAGE__->method_maker_argument_names ]
+  scalar => [ __PACKAGE__->common_method_maker_argument_names ]
 );
 
-sub type { 'date' }
+foreach my $type (__PACKAGE__->available_method_types)
+{
+  __PACKAGE__->method_maker_class($type => 'Rose::DB::Object::MakeMethods::Date');
+  __PACKAGE__->method_maker_type($type => 'date');
+}
 
-sub method_maker_class { 'Rose::DB::Object::MakeMethods::Date' }
-sub method_maker_type  { 'date' }
+sub type { 'date' }
 
 sub should_inline_value
 {
@@ -61,7 +64,7 @@ Rose::DB::Object::Metadata::Column::Date - Date column metadata.
   use Rose::DB::Object::Metadata::Column::Date;
 
   $col = Rose::DB::Object::Metadata::Column::Date->new(...);
-  $col->make_method(...);
+  $col->make_methods(...);
   ...
 
 =head1 DESCRIPTION
@@ -70,21 +73,29 @@ Objects of this class store and manipulate metadata for date columns in a databa
 
 This class inherits from L<Rose::DB::Object::Metadata::Column>. Inherited methods that are not overridden will not be documented a second time here.  See the L<Rose::DB::Object::Metadata::Column> documentation for more information.
 
-=head1 OBJECT METHODS
+=head1 METHOD MAP
 
 =over 4
 
-=item B<default [VALUE]>
+=item C<get_set>
 
-Get or set the default value of the column.
+L<Rose::DB::Object::MakeMethods::Generic>, L<date|Rose::DB::Object::MakeMethods::Date/date>, ...
 
-=item B<method_maker_class>
+=item C<get>
 
-Returns L<Rose::DB::Object::MakeMethods::Date>.
+L<Rose::DB::Object::MakeMethods::Date>, L<date|Rose::DB::Object::MakeMethods::Date/date>, ...
 
-=item B<method_maker_type>
+=item C<get_set>
 
-Returns C<date>.
+L<Rose::DB::Object::MakeMethods::Date>, L<date|Rose::DB::Object::MakeMethods::Date/date>, ...
+
+=back
+
+See the L<Rose::DB::Object::Metadata::Column|Rose::DB::Object::Metadata::Column/"MAKING METHODS"> documentation for an explanation of this method map.
+
+=head1 OBJECT METHODS
+
+=over 4
 
 =item B<parse_value DB, VALUE>
 
