@@ -11,7 +11,7 @@ our $VERSION = '0.02';
 
 __PACKAGE__->delete_method_maker_argument_names('length');
 
-__PACKAGE__->add_method_maker_argument_names
+__PACKAGE__->add_common_method_maker_argument_names
 (
   qw(precision scale)
 );
@@ -19,7 +19,7 @@ __PACKAGE__->add_method_maker_argument_names
 Rose::Object::MakeMethods::Generic->make_methods
 (
   { preserve_existing => 1 },
-  scalar => [ __PACKAGE__->method_maker_argument_names ]
+  scalar => [ __PACKAGE__->common_method_maker_argument_names ]
 );
 
 sub type { 'numeric' }
@@ -54,7 +54,7 @@ Rose::DB::Object::Metadata::Column::Numeric - Numeric column metadata.
   use Rose::DB::Object::Metadata::Column::Numeric;
 
   $col = Rose::DB::Object::Metadata::Column::Numeric->new(...);
-  $col->make_method(...);
+  $col->make_methods(...);
   ...
 
 =head1 DESCRIPTION
@@ -63,21 +63,29 @@ Objects of this class store and manipulate metadata for numeric columns in a dat
 
 This class inherits from L<Rose::DB::Object::Metadata::Column::Scalar>. Inherited methods that are not overridden will not be documented a second time here.  See the L<Rose::DB::Object::Metadata::Column::Scalar> documentation for more information.
 
-=head1 OBJECT METHODS
+=head1 METHOD MAP
 
 =over 4
 
-=item B<default [VALUE]>
+=item C<get_set>
 
-Get or set the default value of the column.
+L<Rose::DB::Object::MakeMethods::Generic>, L<scalar|Rose::DB::Object::MakeMethods::Generic/scalar>, C<interface =E<gt> 'get_set', ...>
 
-=item B<method_maker_class>
+=item C<get>
 
-Returns L<Rose::DB::Object::MakeMethods::Generic>.
+L<Rose::DB::Object::MakeMethods::Generic>, L<scalar|Rose::DB::Object::MakeMethods::Generic/scalar>, C<interface =E<gt> 'get', ...>
 
-=item B<method_maker_type>
+=item C<get_set>
 
-Returns C<scalar>.
+L<Rose::DB::Object::MakeMethods::Generic>, L<scalar|Rose::DB::Object::MakeMethods::Generic/scalar>, C<interface =E<gt> 'set', ...>
+
+=back
+
+See the L<Rose::DB::Object::Metadata::Column|Rose::DB::Object::Metadata::Column/"MAKING METHODS"> documentation for an explanation of this method map.
+
+=head1 OBJECT METHODS
+
+=over 4
 
 =item B<precision [INT]>
 
